@@ -108,8 +108,7 @@ def list_pytype_files(suffix):
     filenames = loader.get_zipfile().namelist()  # pytype: disable=attribute-error
   except AttributeError:
     # List directory using the file system
-    for f in list_files(get_full_path(suffix)):
-      yield f
+    yield from list_files(get_full_path(suffix))
   else:
     for filename in filenames:
       directory = "pytype/" + suffix + "/"
