@@ -127,6 +127,7 @@ class _NameInOuterClassErrorDetails(_NameErrorDetails):
   """Name error details for a name defined in an outer class."""
 
   def __init__(self, attr, prefix, class_name):
+    super().__init__()
     self._attr = attr
     self._prefix = prefix
     self._class_name = class_name
@@ -142,8 +143,10 @@ class _NameInOuterClassErrorDetails(_NameErrorDetails):
 
 
 class _NameInOuterFunctionErrorDetails(_NameErrorDetails):
+  """Name error details for a name defined in an outer function."""
 
   def __init__(self, attr, outer_scope, inner_scope):
+    super().__init__()
     self._attr = attr
     self._outer_scope = outer_scope
     self._inner_scope = inner_scope
@@ -1134,3 +1137,17 @@ def to_coroutine(state, obj, top, ctx):
   for b in obj.bindings:
     state = _binding_to_coroutine(state, b, bad_bindings, ret, top, ctx)
   return state, ret
+
+
+def adjust_block_returns(code, block_returns):
+  """Adjust line numbers for return statements in with blocks."""
+
+  rets = {k: iter(v) for k, v in block_returns}
+  for block in code.order:
+    for op in block:
+      if op.__class__.__name__ == "RETURN_VALUE":
+        if op.line in rets:
+          lines = rets[op.line]
+          new_line = next(lines, None)
+          if new_line:
+            op.line = new_line
